.. _testExample-name:

!!!!!!!!!!!
testExample
!!!!!!!!!!!

.. meta::
   :keywords: testExample, test, special, conditions

.. index:: testExample, test, special, conditions

.. _testExample-title:

Test Special Conditions
#######################

.. contents::
   :local:

.. meta::
   :keywords: camel, case

.. index:: camel, case

.. _testExample@Camel Case:

Camel Case
**********
This page name uses a capital letter, instead of an underbar,
to separate the words test and example.

.. meta::
   :keywords: code, in, list

.. index:: code, in, list

.. _testExample@Code Command in List:

Code Command in List
********************
#. The ``{xrst_code py}`` cannot be on the first line of a list item.

   .. literalinclude:: ../../example/test.py
      :lines: 23-26
      :language: py

#. This is the second item for this list

.. meta::
   :keywords: no, newline, at, end

.. index:: no, newline, at, end

.. _testExample@No Newline at End of File:

No Newline at End of File
*************************
This example file does not have a newline at the end.

.. _testExample@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/test.py
   :language: py
